@@ -249,6 +249,15 @@ class LocalPorvider(BaseProvider):
         """
         return TDP.get_daily_dly_prices(instruments,fields,start_date,end_date)
 
+    def daily_barra_dly_data(self,instruments:list,fields:list,start_date:str,end_date:str):
+        """
+            table_name: 'CNE5S_100_Asset_Data'
+            input: instruments,start_date,end_date
+            output: DataFrame
+            fields: barra_factors
+        """
+        return TDP.get_barra_dly_data(instruments,fields,start_date,end_date)
+
     def daily_barra_rates(self,instruments:list,fields:list,start_date:str,end_date:str):
         """
             table_name: 'CNE5S_Rates'
@@ -605,7 +614,7 @@ class LocalPorvider(BaseProvider):
         """
         return CDP.consus_rolling(instruments,fields,foreward_type,**kws)
 
-    def stk_rating(self,instruments,fields = None,window_days = 'fy1',**kws):
+    def stk_rating(self,instruments,fields = None,window_days = '30d',**kws):
         """
             table_name: 'AShareStockRatingConsus'
             input:instruments:List(str),fields:List(str)
@@ -620,7 +629,6 @@ class LocalPorvider(BaseProvider):
         """
             table_name: 'CON_FORECAST_STK'
             input:instruments:List(str),fields:List(str)
-                  window_days: 30d,90d,180d
                   optional: start_date:str,end_date:str,by [ann_date,reports_period]
             output: DataFrame
             fields : ...
@@ -629,9 +637,8 @@ class LocalPorvider(BaseProvider):
 
     def suntime_confc_roll_stk(self,instruments,fields = None,**kws):
         """
-            table_name: 'CON_FORECAST_STK'
+            table_name: 'CON_FORECAST_STK_ROLL'
             input:instruments:List(str),fields:List(str)
-                  window_days: 30d,90d,180d
                   optional: start_date:str,end_date:str,by [ann_date,reports_period]
             output: DataFrame
             fields : ...
@@ -642,14 +649,17 @@ class LocalPorvider(BaseProvider):
         """
             table_name: 'RPT_FORECAST_STK'
             input:instruments:List(str),fields:List(str)
-                  window_days: 30d,90d,180d
                   optional: start_date:str,end_date:str,by [ann_date,reports_period]
             output: DataFrame
             fields : ...
         """
         return CDP.suntime_repofc_stk(instruments,fields,**kws)
 
-
+    def suntime_repofc_stk_tc(self,instruments = None,start_date = None,end_date = None):
+        """
+            table_name: 'RPT_FORECAST_STK_TC'
+        """
+        return CDP.suntime_repofc_stk_tc(instruments,start_date,end_date)
 
 
 TDP = getattr(daily,provider_config["TDP"])()
