@@ -1,6 +1,6 @@
 import os
 import abc
-
+import pandas as pd
 from .config import data_path
 from .tools import print_func_time,to_intdate
 from .utils import read_mergeh5
@@ -40,6 +40,7 @@ ashare_sktrating_180d = os.path.join(data_path,r"AShareStockRatingConsus_180D")
 suntime_confc_stk = os.path.join(data_path,r"CON_FORECAST_STK")
 suntime_confc_roll_stk = os.path.join(data_path,r"CON_FORECAST_ROLL_STK")
 suntime_repofc_stk = os.path.join(data_path,r"RPT_FORECAST_STK")
+suntime_repofc_stk_tc = os.path.join(data_path,r"RPT_FORECAST_STK_TC")
 
 class BaseConsusDataProvider(abc.ABC):
 
@@ -100,4 +101,18 @@ class LoacalConsusProvider(BaseConsusDataProvider):
 
     @print_func_time
     def suntime_repofc_stk(self,instruments,fields,**kws):
-        return self.get_repo_data(suntime_repofc_stk,instruments,fields,tidx = ["create_date"],**kws)
\ No newline at end of file
+        return self.get_repo_data(suntime_repofc_stk,instruments,fields,tidx = ["create_date"],**kws)
+
+    @print_func_time
+    def suntime_repofc_stk_tc(self,instruments = None,start_date = None,end_date = None):
+        df = pd.read_hdf(os.path.join(suntime_repofc_stk_tc,'all.h5'),"data")
+        try:
+            df = df.loc[df.index.get_level_values["stockcode"].isin(instruments)]
+            if (start_date is not None) & (end_date is not None):
+                start_date,end_date = to_intdate(start_date),to_intdate(end_date)
+                dateindices=df.index.get_level_values["create_date"]
+                df = df.loc[(dateindices <= end_date)&(dateindices >= start_date)]
+            return df
+        except KeyError:
+            print('Index %s info not found')
+            return pd.DataFrame()
\ No newline at end of file
