@@ -27,6 +27,7 @@ ashare_rates = os.path.join(data_path,r"CNE5_Rates")
 ashare_exposure = os.path.join(data_path,r"CNE5S_100_Asset_Exposure")
 ashare_fact_cov = os.path.join(data_path,r"CNE5S_100_Covariance")
 ashare_fact_ret = os.path.join(data_path,r"CNE5S_100_DlyFacRet")
+ashare_assdata = os.path.join(data_path,r"CNE5S_100_Asset_Data")
 
 aswsindexeod = os.path.join(data_path,r'ASWSIndexEOD')
 aindex_eod_price = os.path.join(data_path,r'AIndexEODPrices')
@@ -126,6 +127,10 @@ class TradeDayInfoProvider(BaseDailyTSInfoProvider):
     def get_daily_ashare_exposure(self,instruments,fields,start_date,end_date):
         return self.get_daily_data(ashare_exposure,instruments,fields = fields ,start_date = start_date,end_date = end_date)
 
+    @print_func_time
+    def get_barra_dly_data(self,instruments,fields,start_date,end_date):
+        return self.get_daily_data(ashare_assdata,instruments,fields = fields ,start_date = start_date,end_date = end_date)
+
     @print_func_time
     def get_daily_ashare_faccov(self,instruments,fields,start_date,end_date):
         return self.get_daily_data(ashare_fact_cov,instruments,fields = fields ,start_date = start_date,end_date = end_date)
